##  Overview
SAP LeanIX is introducing the Survey API v1 (survey/v1) to replace the legacy Poll API v2 (poll/v2). The legacy Poll API v2 remains available during a transition period so that you can migrate your integrations at your own pace. For migration steps, see [What You Need to Do](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api?locale=en-US&state=PRODUCTION&version=CLOUD#loiob13f241cc2e847d6b4ec3201fb4cf786__what_you_need_to_do).
Base URL changes:
  * Legacy: https://{SUBDOMAIN}.leanix.net/services/poll/v2
  * New: https://{SUBDOMAIN}.leanix.net/services/survey/v1
